@@ -58,7 +58,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                                 "pump.io/tryit.html</a>")
                                          + "<br><br>"
                                          + tr("If you need help: %1")
-                                           .arg("<a href=\"https://pumpio.readthedocs.org"
+                                           .arg("<a href=\"https://pumpio.readthedocs.io"
                                                 "/en/latest/userguide.html\">"
                                                 + tr("Pump.io User Guide")
                                                 + "</a>"),
