@@ -40,6 +40,7 @@ class ASActivity : public QObject
 
 public:
     explicit ASActivity(QVariantMap activityMap,
+                        QString userId,
                         QObject *parent = 0);
     ~ASActivity();
 
@@ -93,6 +94,8 @@ private:
 
     QStringList recipientsIdList;
 
+    QString ownUserId;
+
     bool shared;
     QString sharedByName;
     QString sharedById;
