@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -59,38 +59,62 @@ ASObject::ASObject(QVariantMap objectMap,
 
     if (type == "image")
     {
-        // See if there's a proxy URL for the image first (for private images)
-        imageUrl = objectMap.value("fullImage").toMap().value("pump_io").toMap().value("proxyURL").toString();
-        qDebug() << "Trying Proxyed fullImage";
+        /* Get the "small" version.
+         * See if there's a proxy URL for the image first
+         * (for private images on remote servers)
+         */
+        qDebug() << "Trying Proxyed thumbnail image";
+        smallImageUrl = objectMap.value("image").toMap()
+                                 .value("pump_io").toMap()
+                                 .value("proxyURL").toString();
 
-        // if that's empty, try the "small" version
-        if (imageUrl.isEmpty())
+        // And if that's empty, use regular image->url
+        if (smallImageUrl.isEmpty())
         {
-            qDebug() << "Trying Proxyed thumbnail image";
-            imageUrl = objectMap.value("image").toMap().value("pump_io").toMap().value("proxyURL").toString();
+            qDebug() << "Trying direct thumbnail image";
+            smallImageUrl = objectMap.value("image").toMap()
+                                     .value("url").toString();
         }
 
-        // If that's also empty, use regular fullImage->url field
+
+        // Same for the full size image
+        imageUrl = objectMap.value("fullImage").toMap()
+                            .value("pump_io").toMap()
+                            .value("proxyURL").toString();
+        qDebug() << "Trying Proxyed fullImage";
+
+        // If that's empty, use regular fullImage->url field
         if (imageUrl.isEmpty())
         {
             qDebug() << "Trying direct fullImage";
-            imageUrl = objectMap.value("fullImage").toMap().value("url").toString();
+            imageUrl = objectMap.value("fullImage").toMap()
+                                .value("url").toString();
         }
 
-        // And if that is ALSO empty, use regular image->url
+        imageWidth = objectMap.value("fullImage").toMap()
+                              .value("width").toInt();
+        imageHeight = objectMap.value("fullImage").toMap()
+                               .value("height").toInt();
+
+        // If it's STILL empty, use the thumbnail also as full image
         if (imageUrl.isEmpty())
         {
-            qDebug() << "Trying direct thumbnail image";
-            imageUrl = objectMap.value("image").toMap().value("url").toString();
-        }
+            imageUrl = smallImageUrl;
+            imageWidth = objectMap.value("image").toMap()
+                                  .value("width").toInt();
+            imageHeight = objectMap.value("image").toMap()
+                                   .value("height").toInt();
+        }        
 
-        qDebug() << "postImage:" << imageUrl;
+        qDebug() << "postImage:" << imageUrl << "> Small:" << smallImageUrl;
 
         // To have a filename with extension, even when downloading from proxyURL's
-        attachmentPureUrl = objectMap.value("fullImage").toMap().value("url").toString();
+        attachmentPureUrl = objectMap.value("fullImage").toMap()
+                                     .value("url").toString();
         if (attachmentPureUrl.isEmpty())
         {
-            attachmentPureUrl = objectMap.value("image").toMap().value("url").toString();
+            attachmentPureUrl = objectMap.value("image").toMap()
+                                         .value("url").toString();
         }
     }
 
@@ -101,7 +125,9 @@ ASObject::ASObject(QVariantMap objectMap,
         // To have a filename with extension, even when downloading from proxyURL's
         attachmentPureUrl = objectMap.value("stream").toMap().value("url").toString();
 
-        audioUrl = objectMap.value("stream").toMap().value("pump_io").toMap().value("proxyURL").toString();
+        audioUrl = objectMap.value("stream").toMap()
+                            .value("pump_io").toMap()
+                            .value("proxyURL").toString();
         if (audioUrl.isEmpty())
         {
             qDebug() << "No proxyed link to audio, fetching regular link";
@@ -115,7 +141,9 @@ ASObject::ASObject(QVariantMap objectMap,
         // To have a filename with extension, even when downloading from proxyURL's
         attachmentPureUrl = objectMap.value("stream").toMap().value("url").toString();
 
-        videoUrl = objectMap.value("stream").toMap().value("pump_io").toMap().value("proxyURL").toString();
+        videoUrl = objectMap.value("stream").toMap()
+                            .value("pump_io").toMap()
+                            .value("proxyURL").toString();
         if (videoUrl.isEmpty())
         {
             qDebug() << "No proxyed link to video, fetching regular link";
@@ -130,7 +158,9 @@ ASObject::ASObject(QVariantMap objectMap,
         attachmentPureUrl = objectMap.value("fileUrl").toString();
 
         // FIXME: there are no proxyURL for misc files ATM; not my fault though =)
-        fileUrl = objectMap.value("fileUrl").toMap().value("pump_io").toMap().value("proxyURL").toString();
+        fileUrl = objectMap.value("fileUrl").toMap()
+                           .value("pump_io").toMap()
+                           .value("proxyURL").toString();
         if (fileUrl.isEmpty())
         {
             qDebug() << "No proxyed link to general file, fetching regular link";
@@ -145,8 +175,10 @@ ASObject::ASObject(QVariantMap objectMap,
     // If it's a group, get member count, etc.
     if (type == "group")
     {
-        memberCount = objectMap.value("members").toMap().value("totalItems").toInt();
-        memberUrl = objectMap.value("members").toMap().value("url").toString();
+        memberCount = objectMap.value("members").toMap()
+                               .value("totalItems").toInt();
+        memberUrl = objectMap.value("members").toMap()
+                             .value("url").toString();
     }
 
 
@@ -390,6 +422,21 @@ QString ASObject::getImageUrl()
     return this->imageUrl;
 }
 
+QString ASObject::getSmallImageUrl()
+{
+    return this->smallImageUrl;
+}
+
+int ASObject::getImageWidth()
+{
+    return this->imageWidth;
+}
+
+int ASObject::getImageHeight()
+{
+    return this->imageHeight;
+}
+
 QString ASObject::getAudioUrl()
 {
     return this->audioUrl;
