@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -64,6 +64,9 @@ public:
     QString getContent();
 
     QString getImageUrl();
+    QString getSmallImageUrl();
+    int getImageWidth();
+    int getImageHeight();
     QString getAudioUrl();
     QString getVideoUrl();
     QString getFileUrl();
@@ -129,6 +132,9 @@ private:
     QString content;
 
     QString imageUrl;
+    QString smallImageUrl;
+    int imageWidth;
+    int imageHeight;
     QString audioUrl;
     QString videoUrl;
     QString fileUrl;
