@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ ColorPicker::ColorPicker(QString description,
 
     buttonPixmap = QPixmap(32, 32);
 
-    button = new QPushButton(tr("Change"), this);
+    button = new QPushButton(tr("Change..."), this);
     button->setIconSize(QSize(32, 32));
     button->setDisabled(true); // Disabled initially
     connect(button, SIGNAL(clicked()),
