@@ -307,7 +307,7 @@ void CommenterBlock::updateCommentFromObject(ASObject *object)
         }
     }
 
-    // FIXME: this needs some cheking...
+    // FIXME: this needs some checking...
     commentsWidget->setMinimumHeight(10);
     scrollToBottomTimer->start(500);
 
@@ -326,7 +326,7 @@ void CommenterBlock::setCommentDeletedFromObject(ASObject *object)
         }
     }
 
-    // FIXME: this needs some cheking... and is copied from previous function
+    // FIXME: this needs some checking... and is copied from previous function
     commentsWidget->setMinimumHeight(10);
     scrollToBottomTimer->start(500);
 
@@ -352,7 +352,7 @@ void CommenterBlock::updateAvatarFollowStates()
 }
 
 
-void CommenterBlock::updateShowAllLink(bool firstTry)
+void CommenterBlock::updateShowAllLink()
 {
     QString showAllString;
     if (allCommentsShown)
@@ -361,9 +361,11 @@ void CommenterBlock::updateShowAllLink(bool firstTry)
     }
     else
     {
-        if (firstTry)
+        if (this->currentCommentCount == 0)
         {
-            showAllString = tr("Check for comments");
+            showAllString = QString::fromUtf8("\342\206\273") // Reload symbol
+                            + " &nbsp;" // Another option, magnifying glass: &#128270;
+                            + tr("Check for comments");
         }
         else
         {
@@ -548,7 +550,7 @@ void CommenterBlock::editComment(QString id, QString content)
 
 void CommenterBlock::requestAllComments()
 {
-    emit allCommentsRequested(); // FIXME 1.3: could connect() to this signal directly
+    emit allCommentsRequested(); // FIXME 1.3.x: could connect() to this signal directly
 }
 
 
