@@ -57,7 +57,7 @@ public:
 
     void updateFuzzyTimestamps();
     void updateAvatarFollowStates();
-    void updateShowAllLink(bool firstTry=false);
+    void updateShowAllLink();
     void disableShowAllLink();
 
     void adjustCommentsWidth();
