@@ -123,7 +123,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     toolsMenu->addAction(QIcon::fromTheme("insert-horizontal-rule"),
                          tr("Insert line"),
                          this,
-                         SLOT(insertLine()));
+                         SLOT(insertLine()),
+                         QKeySequence("Ctrl+Shift+L"));
 
     toolsMenu->addSeparator();
 
@@ -433,9 +434,27 @@ void Composer::contextMenuEvent(QContextMenuEvent *event)
  */
 void Composer::insertFromMimeData(const QMimeData *source)
 {
-    // First, check if it's just a link to an image, to offer embedding it
+    /*
+     * Prevent larjona's crash.
+     *
+     * Apparently the QMessageBox will mess with the 'source' pointer
+     * if the contents of the clipboard came from another program.
+     * This causes a segfault when selecting "insert as link".
+     *
+     * To avoid it, all data needed from 'source' will be stored before showing
+     * the message box.
+     *
+     * https://gitlab.com/dianara/dianara-dev/issues/33
+     *
+     */
+
+    QString pastedHtml = source->html();
     QString pastedText = source->text().trimmed();
 
+    bool sourceHasHtml = source->hasHtml();
+
+
+    // First, check if it's just a link to an image, to offer embedding it
     if (pastedText.startsWith("http://")
      || pastedText.startsWith("https://"))
     {
@@ -465,15 +484,18 @@ void Composer::insertFromMimeData(const QMimeData *source)
 
     // If it wasn't just an image link, or offer to embed was rejected, continue
 
+    // WARNING: Avoid accessing 'source' at this point, since the QMessageBox
+    //          might have messed with it
+
     QTextDocument textDocument;
-    if (source->hasHtml())
+    if (sourceHasHtml)
     {
-        textDocument.setHtml(source->html());
+        textDocument.setHtml(pastedHtml);
         qDebug() << "Parsing pasted RICH (HTML) text for links...";
     }
     else
     {
-        textDocument.setPlainText(source->text().trimmed());
+        textDocument.setPlainText(pastedText);
         qDebug() << "Parsing pasted PLAIN text for links...";
     }
 
