@@ -427,6 +427,11 @@ void ConfigDialog::createTimelinesPage()
                                             "This is a suffix, after a number"));
     snippetLimitSpinbox->setValue(globalObj->getSnippetsCharLimit());
 
+    snippetLimitHlSpinbox = new QSpinBox(this);
+    snippetLimitHlSpinbox->setRange(5, 10000);
+    snippetLimitHlSpinbox->setSuffix(snippetLimitSpinbox->suffix());
+    snippetLimitHlSpinbox->setValue(globalObj->getSnippetsCharLimitHl());
+
     mfAvatarSizeCombobox = this->newAvatarComboBox();
     mfAvatarSizeCombobox->setCurrentIndex(globalObj->getMfAvatarIndex());
 
@@ -440,7 +445,7 @@ void ConfigDialog::createTimelinesPage()
                                    postsPerPageMainSpinbox);
     timelinesOptionsLayout->addRow(tr("Posts per page, &other timelines"),
                                    postsPerPageOtherSpinbox);
-    timelinesOptionsLayout->addRow(tr("Show information for deleted posts"), // FIXME?
+    timelinesOptionsLayout->addRow(tr("Show information for deleted posts"),
                                    showDeletedCheckbox);
     timelinesOptionsLayout->addRow(tr("Hide duplicated posts"),
                                    hideDuplicatesCheckbox);
@@ -451,6 +456,8 @@ void ConfigDialog::createTimelinesPage()
                                    minorFeedSnippetsCombobox);
     timelinesOptionsLayout->addRow(tr("Snippet limit"),
                                    snippetLimitSpinbox);
+    timelinesOptionsLayout->addRow(tr("Snippet limit when highlighted"),
+                                   snippetLimitHlSpinbox);
     timelinesOptionsLayout->addRow(tr("Minor feed avatar sizes"),  // tmp string
                                    mfAvatarSizeCombobox);
 
@@ -612,6 +619,9 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
     notifyHLMWCheckbox = new QCheckBox(this);
     notifyHLMWCheckbox->setChecked(settings->value("notifyHLMW",
                                                    true).toBool());
+    notifyErrorsCheckbox = new QCheckBox(this);
+    notifyErrorsCheckbox->setChecked(settings->value("notifyErrors",
+                                                     true).toBool());
 
     this->syncNotifierOptions();
 
@@ -638,6 +648,8 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
                                       notifyNewMWCheckbox);
     notificationOptionsLayout->addRow(tr("Highlighted activities in minor feed"),
                                       notifyHLMWCheckbox);
+    notificationOptionsLayout->addRow(tr("Important errors"),
+                                      notifyErrorsCheckbox);
 
     notificationOptionsWidget = new QWidget(this);
     notificationOptionsWidget->setLayout(notificationOptionsLayout);
@@ -724,7 +736,8 @@ void ConfigDialog::syncNotifierOptions()
                                              notifyNewTLCheckbox->isChecked(),
                                              notifyHLTLCheckbox->isChecked(),
                                              notifyNewMWCheckbox->isChecked(),
-                                             notifyHLMWCheckbox->isChecked());
+                                             notifyHLMWCheckbox->isChecked(),
+                                             notifyErrorsCheckbox->isChecked());
 }
 
 
@@ -838,10 +851,12 @@ void ConfigDialog::saveConfiguration()
                       this->hideDuplicatesCheckbox->isChecked());
     settings.setValue("jumpToNewOnUpdate",
                       this->jumpToNewCheckbox->isChecked());
-    settings.setValue("minorFeedSnippets",
+    settings.setValue("mfSnippetsType",
                       this->minorFeedSnippetsCombobox->currentIndex());
-    settings.setValue("snippetsCharLimit",
+    settings.setValue("snippetCharLimit",
                       this->snippetLimitSpinbox->value());
+    settings.setValue("snippetCharLimitHl",
+                      this->snippetLimitHlSpinbox->value());
     settings.setValue("minorFeedAvatarIndex",
                       this->mfAvatarSizeCombobox->currentIndex());
 
@@ -852,6 +867,7 @@ void ConfigDialog::saveConfiguration()
                                            this->jumpToNewCheckbox->isChecked(),
                                            this->minorFeedSnippetsCombobox->currentIndex(),
                                            this->snippetLimitSpinbox->value(),
+                                           this->snippetLimitHlSpinbox->value(),
                                            this->mfAvatarSizeCombobox->currentIndex());
 
     // Posts
@@ -908,10 +924,11 @@ void ConfigDialog::saveConfiguration()
     // Notifications
     settings.setValue("showNotifications",
                       this->notificationStyleCombobox->currentIndex());
-    settings.setValue("notifyNewTL", this->notifyNewTLCheckbox->isChecked());
-    settings.setValue("notifyHLTL",  this->notifyHLTLCheckbox->isChecked());
-    settings.setValue("notifyNewMW", this->notifyNewMWCheckbox->isChecked());
-    settings.setValue("notifyHLMW",  this->notifyHLMWCheckbox->isChecked());
+    settings.setValue("notifyNewTL",  this->notifyNewTLCheckbox->isChecked());
+    settings.setValue("notifyHLTL",   this->notifyHLTLCheckbox->isChecked());
+    settings.setValue("notifyNewMW",  this->notifyNewMWCheckbox->isChecked());
+    settings.setValue("notifyHLMW",   this->notifyHLMWCheckbox->isChecked());
+    settings.setValue("notifyErrors", this->notifyErrorsCheckbox->isChecked());
     this->syncNotifierOptions();
     this->globalObj->syncNotificationSettings(); // FIXME, still empty
 
@@ -998,6 +1015,7 @@ void ConfigDialog::toggleNotificationDetails(int currentOption)
     this->notifyHLTLCheckbox->setEnabled(state);
     this->notifyNewMWCheckbox->setEnabled(state);
     this->notifyHLMWCheckbox->setEnabled(state);
+    this->notifyErrorsCheckbox->setEnabled(state);
 }
 
 
