@@ -61,7 +61,7 @@ ContactCard::ContactCard(PumpController *pumpController,
     nameFont.setBold(true);
     nameFont.setUnderline(true);
 
-    this->contactName = asPerson->getName();
+    this->contactName = asPerson->getName(); // WithFallback()? FIXME
     this->contactId = asPerson->getId();
     this->contactUrl = asPerson->getUrl();
     this->contactOutbox = asPerson->getOutboxLink();
@@ -117,12 +117,14 @@ ContactCard::ContactCard(PumpController *pumpController,
     {
         if (contactName.isEmpty())
         {
-            this->setToolTip(tr("This user doesn't have a biography"));
+            this->setToolTip("<b></b>"
+                             + tr("This user doesn't have a biography"));
         }
         else
         {
-            this->setToolTip(tr("No biography for %1",
-                                "%1=contact name").arg(contactName));
+            this->setToolTip("<b></b>"
+                             + tr("No biography for %1",
+                                  "%1=contact name").arg(contactName));
         }
     }
 
@@ -246,7 +248,6 @@ bool ContactCard::setAvatar(QString avatarFilename)
     {
         avatarLabel->setPixmap(avatarPixmap);
         validAvatar = true;
-        qDebug() << "ContactCard: Using cached avatar";
     }
 
 
@@ -283,21 +284,27 @@ QString ContactCard::getId()
 void ContactCard::followContact()
 {
     this->pController->followContact(this->contactId);
-    this->setButtonToUnfollow();
+    this->setButtonToUnfollow(); // FIXME: should wait for proper signal
 }
 
 
 void ContactCard::unfollowContact()
 {
+    QString nameWithId = ASPerson::makeNameIdString(this->contactName,
+                                                    this->contactId);
+
     int confirmation = QMessageBox::question(this, tr("Stop following?"),
-                                             tr("Are you sure you want to stop following %1?")
-                                             .arg(this->contactId),
-                                             tr("&Yes, stop following"), tr("&No"), "", 1, 1);
+                                             tr("Are you sure you want to "
+                                                "stop following %1?")
+                                             .arg(nameWithId),
+                                             tr("&Yes, stop following"),
+                                             tr("&No"),
+                                             "", 1, 1);
 
     if (confirmation == 0)
     {
         this->pController->unfollowContact(this->contactId);
-        this->setButtonToFollow();
+        this->setButtonToFollow(); // FIXME: should wait for proper signal
     }
 }
 
