@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,9 @@ ContactManager::ContactManager(PumpController *pumpController,
     this->pController = pumpController;
     this->globalObj = globalObject;
 
+    this->followingManually = false;
+
+
     // After receiving a contact list, update it
     connect(pController, SIGNAL(contactListReceived(QString,QVariantList,int)),
             this, SLOT(setContactListsContents(QString,QVariantList,int)));
@@ -35,6 +38,13 @@ ContactManager::ContactManager(PumpController *pumpController,
     connect(pController, SIGNAL(listsListReceived(QVariantList)),
             this, SLOT(setListsListContents(QVariantList)));
 
+    // After having checked if a webfinger ID is valid, follow it (or not)
+    connect(pController, SIGNAL(contactVerified(QString,int,bool,QString)),
+            this, SLOT(followContact(QString,int,bool,QString)));
+
+    // If a person can't be followed at the moment, re-enable widgets to try again
+    connect(pController, SIGNAL(cannotFollowNow(QString)),
+            this, SLOT(onCantFollowNow(QString)));
 
 
     mainLayout = new QVBoxLayout();
@@ -58,7 +68,7 @@ ContactManager::ContactManager(PumpController *pumpController,
     connect(addressLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(toggleFollowButton(QString)));
     connect(addressLineEdit, SIGNAL(returnPressed()),
-            this, SLOT(followContact()));
+            this, SLOT(validateContactId()));
 
     enterAddressLabel->setBuddy(addressLineEdit);
 
@@ -69,7 +79,7 @@ ContactManager::ContactManager(PumpController *pumpController,
                                    this);
     followButton->setDisabled(true); // Disabled until an address is typed
     connect(followButton, SIGNAL(clicked()),
-            this, SLOT(followContact()));
+            this, SLOT(validateContactId()));
     topLayout->addWidget(enterAddressLabel);
     topLayout->addWidget(addressLineEdit);
     topLayout->addWidget(followButton);
@@ -81,7 +91,8 @@ ContactManager::ContactManager(PumpController *pumpController,
     // Widgets for list of 'following' and 'followers'
     this->followingWidget = new ContactList(this->pController,
                                             this->globalObj,
-                                            "following", this);
+                                            "following",
+                                            this);
     connect(pController, SIGNAL(contactFollowed(ASPerson*)),
             followingWidget, SLOT(addSingleContact(ASPerson*)));
     connect(pController, SIGNAL(contactUnfollowed(ASPerson*)),
@@ -93,7 +104,8 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     this->followersWidget = new ContactList(this->pController,
                                             this->globalObj,
-                                            "followers", this);
+                                            "followers",
+                                            this);
 
 
     // Widget for the list of 'person lists'
@@ -167,6 +179,7 @@ ContactManager::ContactManager(PumpController *pumpController,
 
 
 
+
     this->followersCount = 0;
     this->followingCount = 0;
     this->listsCount = 0;
@@ -241,17 +254,26 @@ void ContactManager::exportContactsToFile(QString listType)
 
     if (listType == "following")
     {
-        exportFile.write(this->followingWidget->getContactsStringForExport().toLocal8Bit());
+        exportFile.write(this->followingWidget->getContactsStringForExport()
+                                               .toLocal8Bit());
     }
     else // "followers"
     {
-        exportFile.write(this->followersWidget->getContactsStringForExport().toLocal8Bit());
+        exportFile.write(this->followersWidget->getContactsStringForExport()
+                                               .toLocal8Bit());
     }
+
     exportFile.close();
 }
 
 
 
+void ContactManager::enableManualFollowWidgets()
+{
+    this->addressLineEdit->setEnabled(true);
+    this->followButton->setEnabled(!addressLineEdit->text().isEmpty());
+}
+
 
 /*****************************************************************************/
 /*********************************** SLOTS ***********************************/
@@ -412,8 +434,10 @@ void ContactManager::toggleFollowButton(QString currentAddress)
  * This supports adding webfinger addresses in the form
  * user@hostname or https://host/username.
  *
+ * First step is checking, via Webfinger, if the ID exists and its server is up.
+ *
  */
-void ContactManager::followContact()
+void ContactManager::validateContactId()
 {
     QString address = this->addressLineEdit->text().trimmed();
     bool validAddress = false;
@@ -448,13 +472,135 @@ void ContactManager::followContact()
 
     if (validAddress)
     {
-        qDebug() << "About to follow this address:" << address;
+        this->followingManually = true;
+        this->followingAddress = address;
+
+        this->tabWidget->setFocus(); // Take focus away from the widgets that will be disabled now
+
+        this->addressLineEdit->setDisabled(true);
+        this->followButton->setDisabled(true);
+
         this->pController->followContact(address);
+    }
+}
+
+
+void ContactManager::followContact(QString userId, int httpCode,
+                                   bool requestTimedOut, QString serverVersion)
+{
+    if (httpCode != 200)
+    {
+        QString hostname = userId.split('@').last();
+
+        // FIXME/TMP: Unreliable, future/alternate implementations might not use this
+        bool isPumpServer = serverVersion.contains("pump.io");
+
+        QString specificError;
+        if (httpCode == 404)
+        {
+            if (isPumpServer)
+            {
+                specificError = tr("The server seems to be a Pump server, "
+                                   "but the account does not exist.");
+            }
+            else
+            {
+                specificError = tr("%1 doesn't seem to be a Pump server.",
+                                   "%1 is a hostname")
+                                .arg(hostname);
+            }
+        }
+        else
+        {
+            // Really only error 0 would mean unavailable server
+            // Any other error code probably means the server is not a Pump server
+            specificError = tr("Following this account at this time "
+                               "will probably not work.");
+        }
+
+        // Timeout was reached or general connection error
+        if (requestTimedOut || httpCode == 0)
+        {
+            specificError.append(" "
+                                 + tr("The %1 server seems unavailable.",
+                                      "%1 is a hostname")
+                                   .arg(hostname));
+        }
+
+        if (serverVersion.isEmpty())
+        {
+            serverVersion = tr("Unknown",
+                               "Refers to server version");
+        }
+
+        int choice = QMessageBox::warning(this,
+                      tr("Error"),
+                      "<big>"
+                      + tr("The user address %1 does not exist, or the "
+                           "%2 server is down.")
+                        .arg("<b>" + userId + "</b>")
+                        .arg("<b>" + hostname + "</b>")
+                      + "</big>"
+                        "<br><hr><br>"
+                      + specificError
+                      + "<br><br>"
+                      + tr("Server version") + ": <i>"
+                      + serverVersion
+                      + "</i>"
+                        "<br><br>"
+                      + tr("Check the address, and keep in mind that "
+                           "usernames are case-sensitive.")
+                      + "<br><br><br><br>"
+                      + tr("Do you want to try following this address anyway?")
+                      + "<br>"
+                      + tr("(not recommended)")
+                      + "<br>"
+                        "<br>",
+                      tr("Yes, follow anyway"),
+                      tr("No, cancel"),
+                      "", 1, 1);
+
+        if (choice == 1)
+        {
+            if (followingManually && userId == this->followingAddress)
+            {
+                this->enableManualFollowWidgets();
+                this->addressLineEdit->setFocus(); // Re-focus to try again, maybe
+
+                this->followingManually = false;
+                this->followingAddress.clear();
+            }
+
+            return;
+        }
+    }
+
+    qDebug() << "About to follow this address:" << userId;
+    this->globalObj->setStatusMessage(tr("About to follow %1...")
+                                      .arg("'" + userId + "'"));
+    this->pController->followVerifiedContact(userId);
+
+    if (followingManually && userId == this->followingAddress)
+    {
+        this->enableManualFollowWidgets();
+        this->addressLineEdit->clear(); // Which will disable Follow button again
+
+        this->followingManually = false;
+        this->followingAddress.clear();
 
-        this->addressLineEdit->clear();
         // Activate 'Following' tab
         this->tabWidget->setFocus();
         this->tabWidget->setCurrentIndex(1);
     }
-
 }
+
+
+void ContactManager::onCantFollowNow(QString userId)
+{
+    if (followingManually && userId == this->followingAddress)
+    {
+        this->enableManualFollowWidgets();
+        this->addressLineEdit->setFocus();
+    }
+}
+
