@@ -54,6 +54,9 @@ public:
 signals:
 
 public slots:
+    void onFilterTextChanged(QString text);
+    void onFilterRowChanged(int row);
+
     void addFilter();
     void removeFilter();
 
