@@ -75,8 +75,9 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                 settings.value("showDeletedPosts",     false).toBool(),
                                 settings.value("hideDuplicatedPosts",  false).toBool(),
                                 settings.value("jumpToNewOnUpdate",    false).toBool(),
-                                settings.value("minorFeedSnippets",    0).toInt(),
-                                settings.value("snippetsCharLimit",    200).toInt(),
+                                settings.value("mfSnippetsType",       2).toInt(), // Default: Always
+                                settings.value("snippetCharLimit",     30).toInt(),
+                                settings.value("snippetCharLimitHl",   200).toInt(),
                                 settings.value("minorFeedAvatarIndex", 1).toInt()); // 2nd (32x32) by default
 
 
@@ -210,7 +211,8 @@ QString GlobalObject::getColor(int colorIndex)
 void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
                                          bool showDeleted, bool hideDuplicates,
                                          bool jumpToNew, int minorFeedSnippets,
-                                         int snippetsChars, int mfAvatarIdx)
+                                         int snippetsChars, int snippetsCharsHl,
+                                         int mfAvatarIdx)
 {
     this->postsPerPageMain = pppMain;
     this->postsPerPageOther = pppOther;
@@ -221,6 +223,7 @@ void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
 
     this->minorFeedSnippetsType = minorFeedSnippets;
     this->snippetsCharLimit = snippetsChars;
+    this->snippetsCharLimitHl = snippetsCharsHl;
     this->mfAvatarIndex = mfAvatarIdx;
     this->mfAvatarSize = this->getAvatarSizeForIndex(mfAvatarIdx);
 
@@ -262,6 +265,11 @@ int GlobalObject::getSnippetsCharLimit()
     return this->snippetsCharLimit;
 }
 
+int GlobalObject::getSnippetsCharLimitHl()
+{
+    return this->snippetsCharLimitHl;
+}
+
 int GlobalObject::getMfAvatarIndex()
 {
     return this->mfAvatarIndex;
