@@ -64,7 +64,8 @@ public:
     void syncTimelinesSettings(int pppMain, int pppOther,
                                bool showDeleted, bool hideDuplicates,
                                bool jumpToNew, int minorFeedSnippets,
-                               int snippetsChars, int mfAvatarIdx);
+                               int snippetsChars, int snippetsCharsHl,
+                               int mfAvatarIdx);
     int getPostsPerPageMain();
     int getPostsPerPageOther();
     bool getShowDeleted();
@@ -72,6 +73,7 @@ public:
     bool getJumpToNewOnUpdate();
     int getMinorFeedSnippetsType();
     int getSnippetsCharLimit();
+    int getSnippetsCharLimitHl();
     int getMfAvatarIndex();
     QSize getMfAvatarSize();
 
@@ -190,6 +192,7 @@ private:
     bool jumpToNewOnUpdate;
     int minorFeedSnippetsType;
     int snippetsCharLimit;
+    int snippetsCharLimitHl;
     int mfAvatarIndex;
     QSize mfAvatarSize;
 
