@@ -91,7 +91,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "tooltip to appear.")
                     + "<br><br>");
     helpText.append(tr("If you're new to Pump.io, take a look at this guide:")
-                    + " <a href=\"https://pumpio.readthedocs.org/en/latest/userguide.html\">"
+                    + " <a href=\"https://pumpio.readthedocs.io/en/latest/userguide.html\">"
                     + tr("Pump.io User Guide")
                     + "</a>");
 
@@ -224,10 +224,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append(tr("You can find a list with some Pump.io users "
                        "and other information here:")
                     + "<br>"
-                      "<a href=\"https://static.jpope.org/users.html\">"
-                      "static.jpope.org/users.html</a> - "
                       "<a href=\"https://github.com/e14n/pump.io/wiki/Users-by-language\">"
                     + tr("Users by language")
+                    + "</a> - <a href=\"https://pumpit.info/pumpio/followers\">"
+                    + tr("Followers of Pump.io Community account")
                     + "</a>");
 
 
