@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include <QMessageBox>
 #include <QPushButton>
 #include <QMovie>
+#include <QScrollArea>
 
 #include <QDebug>
 
@@ -45,22 +46,32 @@ class ImageViewer : public QWidget
     Q_OBJECT
 
 public:
-    explicit ImageViewer(QString fileURI,
-                         QString title,
-                         QString suggestedFN,
+    explicit ImageViewer(QString url, QSize imageSize,
+                         QString title, QString suggestedFN,
                          bool isAnimated,
                          QWidget *parent = 0);
     ~ImageViewer();
     void createContextMenu();
+    void loadImage(QString url, QSize expectedSize);
+    void drawImage();
+    void toggleZoomButtons();
+    void updateButtons();
 
 
 signals:
 
 
 public slots:
+    void reloadImage(QString url);
+    void onImageFailed(QString url);
+
     void saveImage();
     void restartAnimation();
 
+    void zoomToFit();
+    void zoomIn();
+    void zoomOut();
+
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
@@ -72,10 +83,17 @@ protected:
 private:
     QVBoxLayout *mainLayout;
     QLabel *imageLabel;
+    QScrollArea *scrollArea;
 
     QHBoxLayout *buttonsLayout;
     QPushButton *saveImageButton;
     QPushButton *restartButton;
+
+    QHBoxLayout *fitFullLayout;
+    QPushButton *fitButton;
+    QPushButton *fullButton;
+    QPushButton *zoomInButton;
+    QPushButton *zoomOutButton;
     QLabel *infoLabel;
     QPushButton *closeButton;
 
@@ -83,11 +101,16 @@ private:
     QAction *saveAction;
     QAction *closeAction;
 
+    QString imageUrl;
+
     QPixmap originalPixmap;
     QString originalFileURI;
     bool imageIsAnimated;
     QMovie *movie;
     QString suggestedFilename;
+
+    bool fitToWindow;
+    float zoomLevel;
 };
 
 #endif // IMAGEVIEWER_H
