@@ -79,6 +79,7 @@
 #include "globalobject.h"
 #include "userposts.h"
 #include "firstrunwizard.h"
+#include "bannernotification.h"
 
 
 class MainWindow : public QMainWindow
@@ -129,6 +130,8 @@ public slots:
 
     void postInit();
 
+    void showErrorPopup(QString message);
+
     void trayControl(QSystemTrayIcon::ActivationReason reason);
     void showTrayFallbackMessage(QString title, QString message);
 
@@ -137,8 +140,11 @@ public slots:
                            QString eMail);
 
     void toggleAutoUpdates(bool checked);
+    void onTimelineAutoupdate();
 
     void updateAllTimelines();
+    void onUpdateRequestViaBanner();
+    void onUpdateDelayedViaBanner();
     void updateMainAndMinorTimelines();
     void updateMainActivityMinorTimelines();
     void updateFavoritesTimeline();
@@ -158,6 +164,7 @@ public slots:
 
     void notifyTimelineUpdate(PumpController::requestTypes timelineType,
                               int newPostCount, int highlightCount,
+                              int directPostCount, int hlByFilterCount,
                               int deletedPostCount, int filteredPostCount,
                               int pendingPostCount);
     void setTimelineTabTitle(PumpController::requestTypes timelineType,
@@ -174,7 +181,6 @@ public slots:
                                int filteredCount,
                                int pendingItemsCount);
 
-    void restartAutoupdateTimer();
 
     void storeAvatar(QByteArray avatarData, QString avatarUrl);
     void storeImage(QByteArray imageData, QString imageUrl);
@@ -337,6 +343,8 @@ private:
     MinorFeed *mentionsFeed;
     MinorFeed *actionsFeed;
 
+    BannerNotification *bannerNotification;
+
     TimeLine *mainTimeline;
     QScrollArea *mainTimelineScrollArea;
 
