@@ -43,7 +43,6 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     itemsLayout = new QVBoxLayout();
     itemsLayout->setContentsMargins(0, 0, 0, 0);
     itemsLayout->setSpacing(1); // Very small spacing
-    itemsLayout->setAlignment(Qt::AlignTop);
 
     // Separator frame, to mark where new items end
     separatorFrame = new QFrame(this);
@@ -69,7 +68,8 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
                                      tr("Older Activities"),
                                      this);
     getOlderButton->setFlat(true);
-    getOlderButton->setToolTip(tr("Get previous minor activities"));
+    getOlderButton->setToolTip("<b></b>"
+                               + tr("Get previous minor activities"));
     connect(getOlderButton, SIGNAL(clicked()),
             this, SLOT(getMoreActivities()));
 
@@ -80,9 +80,10 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     // Main layout
     mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(1, 1, 1, 1);
-    mainLayout->setAlignment(Qt::AlignTop);
     mainLayout->addWidget(getPendingButton);
     mainLayout->addLayout(itemsLayout);
+    mainLayout->addSpacing(8);
+    mainLayout->addStretch();
     mainLayout->addWidget(getOlderButton);
     this->setLayout(mainLayout);
 
@@ -98,7 +99,7 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     demoActivityMap.insert("generator", demoGenerator);
     demoActivityMap.insert("content",   tr("There are no activities to show yet."));
 
-    ASActivity *demoActivity = new ASActivity(demoActivityMap, this);
+    ASActivity *demoActivity = new ASActivity(demoActivityMap, "", this);
 
     MinorFeedItem *demoFeedItem = new MinorFeedItem(demoActivity,
                                                     false, // Not highlighted by filter
@@ -335,7 +336,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "favorite"
      || activity->getVerb() == "like")
     {
-        // FIXME: handle liking of comments (1.3.3)
+        // FIXME: handle liking of comments (1.3.5)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -351,7 +352,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "unfavorite"
      || activity->getVerb() == "unlike")
     {
-        // FIXME: handle unliking of comments (1.3.3)
+        // FIXME: handle unliking of comments (1.3.5)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -506,7 +507,9 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
     {
         itemIsNew = false;
 
-        ASActivity *activity = new ASActivity(activityVariant.toMap(), this);
+        ASActivity *activity = new ASActivity(activityVariant.toMap(),
+                                              pController->currentUserId(),
+                                              this);
 
         int filtered = fChecker->validateActivity(activity);
 
