@@ -139,41 +139,35 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     // Highlight this item if it's about the user, with different colors
     itemHighlightType = -1; // False
-    QString highlightItemColor;
 
     // We are in the recipient list of the activity
-    if (activity->getRecipientsIdList().contains("acct:" + pController->currentUserId()))
+    if (activity->getRecipientsIdList().contains(pController->currentUserId()))
     {
         itemHighlightType = 0;
-        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // Activity is in reply to something made by us
     if (inReplyToAuthorId == pController->currentUserId())
     {
         itemHighlightType = 1;
-        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // We are the object; someone added us, etc.
     if (activity->object()->getId() == pController->currentUserId())
     {
         itemHighlightType = 2;
-        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // The object is ours; someone favorited our note, or something
     if (activity->object()->author()->getId() == pController->currentUserId())
     {
         itemHighlightType = 3;
-        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     //// Special case: highlighting the item because there's a filter rule for it
     if (highlightedByFilter && itemHighlightType == -1) // Only if there's no other reason for HL
     {
         itemHighlightType = 4;
-        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
 
@@ -182,6 +176,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         // Unless the user ID is also empty!
         if (!pController->currentUserId().isEmpty())
         {
+            QString highlightItemColor = this->globalObj->getColor(itemHighlightType);
+
             if (QColor::isValidColor(highlightItemColor)) // Valid color
             {
                 // CSS for horizontal gradient from configured color to transparent
@@ -216,11 +212,21 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
             if (this->globalObj->getMinorFeedSnippetsType() > 0  // Always or any highlighted
              || authorId != pController->currentUserId())        // or highlighted but not ours (0)
             {
-                // FIXME: fix this spaghetti mess!!
+                // FIXME 1.3.5: fix this spaghetti mess!!
                 // TODO: option to not show when the object of the activity is ours
                 // i.e. "JohnDoe liked a note", our note
 
-                QString snippet = activity->generateSnippet(globalObj->getSnippetsCharLimit());
+                int snippetCharLimit;
+                if (this->itemHighlightType == -1)
+                {
+                    snippetCharLimit = globalObj->getSnippetsCharLimit();
+                }
+                else
+                {
+                    snippetCharLimit = globalObj->getSnippetsCharLimitHl();
+                }
+
+                QString snippet = activity->generateSnippet(snippetCharLimit);
                 if (!snippet.isEmpty())
                 {
                     activityDescription.append("&nbsp;<hr>" + snippet);
@@ -424,7 +430,9 @@ void MinorFeedItem::openOriginalPost()
                                this->originalObjectMap.value("author").toMap());
     }
 
-    ASActivity *originalPostActivity = new ASActivity(originalPostMap, this);
+    ASActivity *originalPostActivity = new ASActivity(originalPostMap,
+                                                      pController->currentUserId(),
+                                                      this);
 
     Post *referencedPost = new Post(originalPostActivity,
                                     false, // Not highlighted
