@@ -542,7 +542,7 @@ QString MiscHelpers::mediaHtmlBase(QString postType,
                 + belowMessage +
                 "</small></td></tr>"
                 "</table>"
-                "<br><br>");
+                "<br><br>"); // Double line-break, because the content might not start with <p>
 
     return html;
 }
