@@ -74,7 +74,8 @@ bool FDNotifications::areNotificationsAvailable()
 
 void FDNotifications::setNotificationOptions(int style,
                                              bool notifyNewTL, bool notifyHLTL,
-                                             bool notifyNewMW, bool notifyHLMW)
+                                             bool notifyNewMW, bool notifyHLMW,
+                                             bool notifyErr)
 {
     this->notificationType = style;
 
@@ -82,12 +83,14 @@ void FDNotifications::setNotificationOptions(int style,
     this->notifyHLTimeline   = notifyHLTL;
     this->notifyNewMeanwhile = notifyNewMW;
     this->notifyHLMeanwhile  = notifyHLMW;
+    this->notifyErrors       = notifyErr;
 
     qDebug() << "Notification type set to"
              << this->notificationType
              << "-- FD.o/Qt/none";
     qDebug() << this->notifyNewTimeline << this->notifyHLTimeline
-             << this->notifyNewMeanwhile << this->notifyHLMeanwhile;
+             << this->notifyNewMeanwhile << this->notifyHLMeanwhile
+             << this->notifyErrors;
 }
 
 void FDNotifications::setCurrentUserId(QString newId)
@@ -116,6 +119,11 @@ bool FDNotifications::getNotifyHLMeanwhile()
     return this->notifyHLMeanwhile;
 }
 
+bool FDNotifications::getNotifyErrors()
+{
+    return this->notifyErrors;
+}
+
 
 
 ///////////////////////////////////////////////////////////////////////
