@@ -46,13 +46,15 @@ public:
                                 bool notifyNewTL,
                                 bool notifyHLTL,
                                 bool notifyNewMW,
-                                bool notifyHLMW);
+                                bool notifyHLMW,
+                                bool notifyErr);
     void setCurrentUserId(QString newId);
 
     bool getNotifyNewTimeline();
     bool getNotifyHLTimeline();
     bool getNotifyNewMeanwhile();
     bool getNotifyHLMeanwhile();
+    bool getNotifyErrors();
 
 
     enum notificationTypes
@@ -83,6 +85,7 @@ private:
     bool notifyHLTimeline;
     bool notifyNewMeanwhile;
     bool notifyHLMeanwhile;
+    bool notifyErrors;
 
     QString currentUserId;
 };
