@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <QSlider>
 #include <QPushButton>
 #include <QAction>
+#include <QHideEvent>
 
 #include <QDebug>
 
@@ -55,6 +56,12 @@ public slots:
 
     void onPageNumberEntered();
 
+    void toggleGoButton(int selectedPage);
+
+
+protected:
+    virtual void hideEvent(QHideEvent *event);
+
 
 private:
     QVBoxLayout *mainLayout;
@@ -77,6 +84,8 @@ private:
     QPushButton *closeButton;
 
     QAction *closeAction;
+
+    int initialPage;
 };
 
 #endif // PAGESELECTOR_H
