@@ -44,7 +44,7 @@ Post::Post(ASActivity *activity,
     activity->setParent(this); // reparent the passed activity
 
 
-    leftColumnFrame = new QFrame();
+    leftColumnFrame = new QFrame(this);
 
     ///////////////////////////////////////////////// Highlighting
     this->highlightType = NoHighlight;
@@ -52,8 +52,7 @@ Post::Post(ASActivity *activity,
     QString highlightPostColor;
 
     // Post is adressed to us
-    if (activity->getRecipientsIdList().contains("acct:"
-                                                 + pController->currentUserId()))
+    if (activity->getRecipientsIdList().contains(pController->currentUserId()))
     {
         highlightType = MessageForUserHighlight;
         highlightPostColor = highlightColors.at(0); // Color #1 in config
@@ -364,7 +363,7 @@ Post::Post(ASActivity *activity,
     // Author name
     postAuthorNameLabel = new QLabel(postAuthorName, this);
     postAuthorNameLabel->setTextFormat(Qt::PlainText);
-    postAuthorNameLabel->setWordWrap(true /* make optional */);
+    postAuthorNameLabel->setWordWrap(true); ///////////////// FIXME: make optional
     postAuthorNameLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postAuthorNameLabel->setFont(authorFont);
     postAuthorNameLabel->setToolTip(authorPerson->getTooltipInfo());
@@ -415,13 +414,14 @@ Post::Post(ASActivity *activity,
     postLocationLabel->hide();
 
 
-    if (!activity->isShared())  // When shared, To/CC are shown with share info
+    if (!activity->isShared())  // Because when shared, To/Cc are shown with share info
     {
         if (!activity->getToString().isEmpty())
         {
             this->postToLabel = new QLabel(tr("To") + ": "
                                            + activity->getToString()
-                                           + " &nbsp;"); // Small hack to try to ensure full visibility
+                                           + " &nbsp;", // Small hack to try to ensure full visibility
+                                           this);
             postToLabel->setWordWrap(true);
             postToLabel->setOpenExternalLinks(true);
             postToLabel->setSizePolicy(QSizePolicy::Ignored,
@@ -437,7 +437,8 @@ Post::Post(ASActivity *activity,
         {
             this->postCCLabel = new QLabel(tr("Cc") + ": "
                                            + activity->getCCString()
-                                           + " &nbsp;");
+                                           + " &nbsp;",
+                                           this);
             postCCLabel->setWordWrap(true);
             postCCLabel->setOpenExternalLinks(true);
             postCCLabel->setSizePolicy(QSizePolicy::Ignored,
@@ -545,7 +546,7 @@ Post::Post(ASActivity *activity,
     //////////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////// Right column, content
 
-    rightColumnFrame = new QFrame();
+    rightColumnFrame = new QFrame(this);
     rightColumnFrame->setObjectName("RightFrame"); // For css changes later
 
     rightColumnLayout = new QVBoxLayout();
@@ -610,7 +611,8 @@ Post::Post(ASActivity *activity,
     // Like button
     likeButton = new QPushButton(QIcon::fromTheme("emblem-favorite",
                                                   QIcon(":/images/button-like.png")),
-                                 "*like*");
+                                 "*like*",
+                                 this);
     likeButton->setCheckable(true);
     this->fixLikeButton(activity->object()->isLiked());
     likeButton->setFlat(true);
@@ -626,7 +628,8 @@ Post::Post(ASActivity *activity,
         commentButton = new QPushButton(QIcon::fromTheme("mail-reply-sender",
                                                          QIcon(":/images/button-comment.png")),
                                         tr("Comment",
-                                           "verb, for the comment button"));
+                                           "verb, for the comment button"),
+                                        this);
         commentButton->setToolTip(tr("Reply to this post.")
                                   + "<br>"
                                   + tr("If you select some text, "
@@ -641,7 +644,8 @@ Post::Post(ASActivity *activity,
         // Share button
         shareButton = new QPushButton(QIcon::fromTheme("mail-forward",
                                                        QIcon(":/images/button-share.png")),
-                                      "*share*");
+                                      "*share*",
+                                      this);
         // Note: Gwenview includes 'document-share' icon
         shareButton->setFlat(true);
         shareButton->setFont(buttonsFont);
@@ -663,6 +667,7 @@ Post::Post(ASActivity *activity,
                     this, SLOT(unsharePost()));
             shareButton->setDisabled(true); // FIXME: disabled for 1.2.x, since it doesn't really work
         }
+
         buttonsLayout->addWidget(shareButton, 0, Qt::AlignLeft);
     }
 
@@ -672,7 +677,8 @@ Post::Post(ASActivity *activity,
     {
         editButton = new QPushButton(QIcon::fromTheme("document-edit",
                                                       QIcon(":/images/button-edit.png")),
-                                     tr("Edit"));
+                                     tr("Edit"),
+                                     this);
         editButton->setToolTip("<b></b>"
                                + tr("Modify this post"));
         editButton->setFlat(true);
@@ -683,7 +689,8 @@ Post::Post(ASActivity *activity,
 
         deleteButton = new QPushButton(QIcon::fromTheme("edit-delete",
                                                         QIcon(":/images/button-delete.png")),
-                                       tr("Delete"));
+                                       tr("Delete"),
+                                       this);
         deleteButton->setToolTip("<b></b>"
                                  + tr("Erase this post"));
         deleteButton->setFlat(true);
@@ -832,7 +839,7 @@ Post::Post(ASActivity *activity,
     if (standalone)
     {
         // Set link to "check for comments"
-        this->commenter->updateShowAllLink(true); // firstTry=true
+        this->commenter->updateShowAllLink();
 
         this->updateBestCommentsUrl();
         // If we still don't have a valid URL from our host, proxyURL or not..
@@ -1733,6 +1740,10 @@ void Post::likePost(bool like)
 
     connect(pController, SIGNAL(likeSet()),
             this, SLOT(getAllLikes()));
+
+
+    // Clicking 'Like' doesn't generate a mousePressEvent, so mark as read here
+    this->setPostAsRead();
 }
 
 /*
@@ -1792,7 +1803,15 @@ void Post::commentOnPost()
     }
     this->commenter->setFullMode(initialText);
 
+    // Show "Check for comments" link, if it wasn't present, in some form, already
+    this->commenter->updateShowAllLink();
+
+
     emit commentingOnPost(this->commenter);
+
+
+    // Clicking 'Comment' doesn't generate a mousePressEvent, so mark as read here
+    this->setPostAsRead();
 }
 
 
@@ -1866,6 +1885,10 @@ void Post::setAllComments(QVariantList commentsList, QString originatingPostUrl)
  */
 void Post::sharePost()
 {
+    // Clicking 'Share' doesn't generate a mousePressEvent, so mark as read here
+    this->setPostAsRead();
+
+
     int confirmation = QMessageBox::question(this, tr("Share post?"),
                                              tr("Do you want to share %1's post?")
                                               .arg(this->postAuthorName)
@@ -2052,7 +2075,9 @@ void Post::openParentPost()
     fakeActivityMap.insert("object", this->postParentMap);
     fakeActivityMap.insert("actor",  this->postParentMap.value("author").toMap());
 
-    ASActivity *originalPostActivity = new ASActivity(fakeActivityMap, this);
+    ASActivity *originalPostActivity = new ASActivity(fakeActivityMap,
+                                                      pController->currentUserId(),
+                                                      this);
 
     Post *parentPost = new Post(originalPostActivity,
                                 false, // Not highlighted
