@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -241,7 +241,10 @@ private:
     DownloadWidget *downloadWidget;
 
     QString postTitle;
+    QString postSmallImageUrl;
+    QString postFullImageUrl;
     QString postImageUrl;
+    QSize postImageSize;
     bool postImageIsAnimated;
     bool postImageFailed;
     QString postAudioUrl;
