@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -67,32 +67,28 @@ Publisher::Publisher(PumpController *pumpController,
     QFont titleFont;
     titleFont.setPointSize(titleFont.pointSize() + 1);
     titleFont.setBold(true);
-    titleLabel = new QLabel(tr("Title") + ":");
-    titleLabel->setSizePolicy(QSizePolicy::Minimum,
-                              QSizePolicy::Maximum);
+    titleLabel = new QLabel(tr("Title") + ":", this);
     titleLabel->setFont(titleFont);
     titleLabel->setToolTip(titleTooltip);
 
-    titleLineEdit = new QLineEdit();
-    titleLineEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
-                                 QSizePolicy::Maximum);
+    titleLineEdit = new QLineEdit(this);
     titleLineEdit->setPlaceholderText(tr("Add a brief title for the post here "
                                          "(recommended)"));
     titleLineEdit->setFont(titleFont);
     titleLineEdit->setToolTip(titleTooltip);
 
 
-    pictureLabel = new QLabel();
+    pictureLabel = new QLabel(this);
     pictureLabel->setAlignment(Qt::AlignCenter);
     pictureLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     pictureLabel->hide();
 
 
-    mediaInfoLabel = new QLabel();
+    mediaInfoLabel = new QLabel(this);
     mediaInfoLabel->setWordWrap(true);
     mediaInfoLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
 
-    selectMediaButton = new QPushButton();
+    selectMediaButton = new QPushButton(this);
     selectMediaButton->setSizePolicy(QSizePolicy::MinimumExpanding,
                                      QSizePolicy::Maximum);
     connect(selectMediaButton, SIGNAL(clicked()),
@@ -104,7 +100,8 @@ Publisher::Publisher(PumpController *pumpController,
 
     removeMediaButton = new QPushButton(QIcon::fromTheme("edit-delete",
                                                          QIcon(":/images/button-delete.png")),
-                                        tr("Remove"));
+                                        tr("Remove"),
+                                        this);
     removeMediaButton->setToolTip("<b></b>"
                                   + tr("Cancel the attachment, and go "
                                        "back to a regular note"));
@@ -124,7 +121,7 @@ Publisher::Publisher(PumpController *pumpController,
                                true,  // forPublisher = true
                                this);
     composerBox->setSizePolicy(QSizePolicy::Minimum,
-                               QSizePolicy::Minimum);
+                               QSizePolicy::MinimumExpanding);
     connect(composerBox, SIGNAL(focusReceived()),
             this, SLOT(setFullMode()));
     connect(composerBox, SIGNAL(editingFinished()),
@@ -238,13 +235,13 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(showHighlightedUrl(QString)));
 
     // And these will show "public" or "followers" current selection (in bold)
-    toPublicFollowersLabel = new QLabel();
+    toPublicFollowersLabel = new QLabel(this);
     toPublicFollowersLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     audienceLabelsFont.setBold(true);
     audienceLabelsFont.setItalic(false);
     toPublicFollowersLabel->setFont(audienceLabelsFont);  // Bold
 
-    ccPublicFollowersLabel = new QLabel();
+    ccPublicFollowersLabel = new QLabel(this);
     ccPublicFollowersLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     audienceLabelsFont.setItalic(true);
     ccPublicFollowersLabel->setFont(audienceLabelsFont);  // Bold + italic
@@ -287,7 +284,8 @@ Publisher::Publisher(PumpController *pumpController,
     // The "add..." button holding the menu
     addMediaButton = new QPushButton(QIcon::fromTheme("mail-attachment",
                                                       QIcon(":/images/list-add.png")),
-                                    tr("Ad&d..."));
+                                     tr("Ad&d..."),
+                                     this);
     addMediaButton->setToolTip("<b></b>"
                                + tr("Upload media, like pictures or videos"));
     addMediaButton->setMenu(addMediaMenu);
@@ -300,7 +298,7 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     // Info label for "sending" and other status information
-    statusInfoLabel = new QLabel();
+    statusInfoLabel = new QLabel(this);
     statusInfoLabel->setSizePolicy(QSizePolicy::Maximum,
                                    QSizePolicy::Maximum);
     statusInfoLabel->setAlignment(Qt::AlignCenter);
@@ -313,7 +311,8 @@ Publisher::Publisher(PumpController *pumpController,
     // To send the post
     postButton = new QPushButton(QIcon::fromTheme("mail-send",
                                                   QIcon(":/images/button-post.png")),
-                                  tr("Post", "verb"));
+                                 tr("Post", "verb"),
+                                 this);
     postButton->setToolTip("<b></b>"
                            + tr("Hit Control+Enter to post with the keyboard"));
     connect(postButton, SIGNAL(clicked()),
@@ -321,62 +320,70 @@ Publisher::Publisher(PumpController *pumpController,
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("Cancel"));
+                                   tr("Cancel"),
+                                   this);
     cancelButton->setToolTip("<b></b>"
                              + tr("Cancel the post"));
     connect(cancelButton, SIGNAL(clicked()),
             composerBox, SLOT(cancelPost()));
 
 
-    // Now the layout, starting with the Title field and "picture mode" stuff
+    // Now the layout, starting with the Title field and "media mode" stuff
     titleLayout = new QHBoxLayout();
-    titleLayout->addWidget(titleLabel);
-    titleLayout->addWidget(titleLineEdit);
-    titleLayout->addSpacing(12);
-    titleLayout->addWidget(toolsButton);
+    titleLabel->setContentsMargins(0, 0, 0, 0);
+    titleLayout->addWidget(titleLabel,    0);
+    titleLayout->addSpacing(1);
+    titleLayout->addWidget(titleLineEdit, 2);
+    titleLayout->addSpacing(2);
+    titleLayout->addWidget(toolsButton,   0);
 
-    mainLayout = new QGridLayout();
-    mainLayout->setVerticalSpacing(1);
-    mainLayout->setContentsMargins(1, 1, 1, 1);
-
-    mainLayout->addLayout(titleLayout,         0, 0, 1, 8, Qt::AlignTop | Qt::AlignLeft);
-    mainLayout->addWidget(pictureLabel,        1, 0, 2, 4);
-    mainLayout->addWidget(mediaInfoLabel,      1, 4, 1, 4, Qt::AlignTop);
-    mainLayout->addWidget(selectMediaButton,   2, 4, 1, 2, Qt::AlignBottom | Qt::AlignLeft);
-    mainLayout->addWidget(uploadProgressBar,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
-    mainLayout->addWidget(removeMediaButton,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
-
-    mainLayout->addWidget(composerBox,         3, 0, 3, 8); // 3 rows, 8 columns
-
-    mainLayout->addWidget(toSelectorButton,    6, 0, 1, 1, Qt::AlignLeft);
-    mainLayout->addWidget(ccSelectorButton,    6, 1, 1, 1, Qt::AlignLeft);
-    mainLayout->addWidget(addMediaButton,      6, 3, 1, 2, Qt::AlignCenter);
-    mainLayout->addWidget(statusInfoLabel,     6, 5, 3, 2, Qt::AlignCenter);
-    mainLayout->addWidget(postButton,          6, 7, 1, 1);
+    mediaLayout = new QGridLayout();
+    mediaLayout->setVerticalSpacing(0);
+    mediaLayout->setContentsMargins(0, 0, 0, 0);
+    mediaLayout->addWidget(pictureLabel,        1, 0, 2, 4);
+    mediaLayout->addWidget(mediaInfoLabel,      1, 4, 1, 4, Qt::AlignTop);
+    mediaLayout->addWidget(selectMediaButton,   2, 4, 1, 2, Qt::AlignBottom | Qt::AlignLeft);
+    mediaLayout->addWidget(uploadProgressBar,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
+    mediaLayout->addWidget(removeMediaButton,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
 
+    buttonsLayout = new QGridLayout();
+    buttonsLayout->setVerticalSpacing(0);
+    buttonsLayout->setContentsMargins(0, 0, 0, 0);
+    buttonsLayout->addWidget(toSelectorButton,       0, 0, 1, 1, Qt::AlignLeft);
+    buttonsLayout->addWidget(ccSelectorButton,       0, 1, 1, 1, Qt::AlignLeft);
+    buttonsLayout->addWidget(addMediaButton,         0, 3, 1, 2, Qt::AlignCenter);
+    buttonsLayout->addWidget(statusInfoLabel,        0, 5, 3, 2, Qt::AlignCenter);
+    buttonsLayout->addWidget(postButton,             0, 7, 1, 1);
 
     // The 2 labels holding people's names, if any
-    mainLayout->addWidget(toAudienceLabel,        7, 0, 1, 1);
-    mainLayout->addWidget(ccAudienceLabel,        7, 1, 1, 1);
+    buttonsLayout->addWidget(toAudienceLabel,        1, 0, 1, 1);
+    buttonsLayout->addWidget(ccAudienceLabel,        1, 1, 1, 1);
 
     // The 2 labels holding "public/followers", if selected
-    mainLayout->addWidget(toPublicFollowersLabel, 8, 0, 1, 1);
-    mainLayout->addWidget(ccPublicFollowersLabel, 8, 1, 1, 1);
+    buttonsLayout->addWidget(toPublicFollowersLabel, 2, 0, 1, 1);
+    buttonsLayout->addWidget(ccPublicFollowersLabel, 2, 1, 1, 1);
 
     // Character counter
-    mainLayout->addWidget(charCounterLabel,       8, 3, 1, 2, Qt::AlignCenter);
+    buttonsLayout->addWidget(charCounterLabel,       2, 3, 1, 2, Qt::AlignCenter);
 
     // The "Cancel post" button
-    mainLayout->addWidget(cancelButton,        8, 7, 1, 1);
+    buttonsLayout->addWidget(cancelButton,           2, 7, 1, 1);
 
 #ifdef GROUPSUPPORT
-    groupIdLabel = new QLabel("TO GROUP (ID):");
-    mainLayout->addWidget(groupIdLabel,        9, 0, 1, 1);
-    groupIdLineEdit = new QLineEdit();
-    mainLayout->addWidget(groupIdLineEdit,     9, 1, 1, 7);
+    groupIdLabel = new QLabel("TO GROUP (ID):", this);
+    buttonsLayout->addWidget(groupIdLabel,        3, 0, 1, 1);
+    groupIdLineEdit = new QLineEdit(this);
+    buttonsLayout->addWidget(groupIdLineEdit,     3, 1, 1, 7);
 #endif
 
 
+    mainLayout = new QVBoxLayout();
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setSpacing(0);
+    mainLayout->addLayout(titleLayout,   0);
+    mainLayout->addLayout(mediaLayout,   0);
+    mainLayout->addWidget(composerBox,   2);
+    mainLayout->addLayout(buttonsLayout, 0);
     this->setLayout(mainLayout);
 
 
@@ -747,6 +754,9 @@ void Publisher::setMinimumMode()
 
     this->fullMode = false;
 
+    // Re-enable stuff just in case the POST request never finished
+    this->toggleWidgetsWhileSending(true);
+
 #ifdef GROUPSUPPORT
     this->groupIdLabel->hide();
     this->groupIdLineEdit->hide();
@@ -772,7 +782,7 @@ void Publisher::setFullMode()
     this->composerBox->hideInfoMessage();
     this->setMaximumHeight(2048); // i.e. "unlimited"
 
-    // Re-enable ctrl+shift+v for plaintext paste (disabled to avoid conflicts)
+    // Re-enable ctrl+shift+V for plaintext paste (disabled to avoid conflicts)
     this->composerBox->setPlainPasteEnabled(true);
 
     this->toSelectorButton->show();
@@ -1548,10 +1558,11 @@ void Publisher::findMediaFile()
                 this->pictureLabel->setPixmap(imagePixmap.scaled(320, 180,  // 16:9
                                                                  Qt::KeepAspectRatio,
                                                                  Qt::SmoothTransformation));
-                metaDataString = QString("<br><br>"
-                                         "<b>" +tr("Resolution") + ":</b> %1x%2")
-                                         .arg(imagePixmap.width())
-                                         .arg(imagePixmap.height());
+                metaDataString = "<br><br>"
+                                 "<b>" + tr("Resolution",
+                                            "Image resolution (size)") + ":</b> "
+                                 + MiscHelpers::resolutionString(imagePixmap.width(),
+                                                                 imagePixmap.height());
             }
 
             this->lastUsedDirectory = fileInfo.path();
