@@ -310,7 +310,7 @@ signals:
 
     void avatarUploaded(QString url);
 
-    void showNotification(QString message);
+    void showErrorNotification(QString message);
     void currentJobChanged(QString message);
     void transientStatusBarMessage(QString message);
     void logMessage(QString message, QString url="");
