@@ -41,10 +41,15 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
                          "<li>"
                          "<a href=\"https://www.inventati.org/ppump/usuarios/\">"
                        + tr("PPump user search service at inventati.org")
+                       + "</a>."
+                         "</li>"
+                         "<li>"
+                         "<a href=\"https://pumpit.info/pumpio/followers\">"
+                       + tr("List of Followers for the Pump.io Community account")
                        + "</a>."
                          "</li>"
                          "</ul>"
-                         "<br>", this);
+                         "<br><br>", this);
     explanationLabel->setWordWrap(true);
     explanationLabel->setAlignment(Qt::AlignTop);
     explanationLabel->setMargin(8);
@@ -67,7 +72,8 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
 
     this->closeListButton = new QPushButton(QIcon::fromTheme("window-close",
                                                              QIcon(":/images/button-close.png")),
-                                            "", this);
+                                            "",
+                                            this);
     closeListButton->setSizePolicy(QSizePolicy::Maximum,
                                    QSizePolicy::Maximum);
     closeListButton->setToolTip(tr("Close list"));
@@ -93,7 +99,7 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
     this->mainLayout = new QVBoxLayout();
     this->mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addWidget(explanationLabel);
-    mainLayout->addWidget(getListButton, 1, Qt::AlignCenter);
+    mainLayout->addWidget(getListButton, 1, Qt::AlignTop | Qt::AlignHCenter);
     mainLayout->addLayout(middleLayout);
     mainLayout->addWidget(userList);
     this->setLayout(mainLayout);
