@@ -57,8 +57,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
 
-    // Show date/time when Dianara v1.3.3 was released
-    demoObjectData.insert("published",      "2016-03-21T19:00:00Z");
+    // Show date/time when Dianara v1.3.4 was released
+    demoObjectData.insert("published",      "2016-06-11T19:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -106,7 +106,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
 
                               + "<a href=\"https://jancoding.wordpress.com/dianara\">"
                               + tr("Dianara's blog") + "</a><br><br>"
-                                "<a href=\"https://pumpio.readthedocs.org/en/latest/userguide.html\">"
+                                "<a href=\"https://pumpio.readthedocs.io/en/latest/userguide.html\">"
                               + tr("Pump.io User Guide")
                               + "</a>"
                               + "<br><br>");
@@ -360,7 +360,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     // Add the default "demo" post
     if (timelineType != PumpController::UserTimelineRequest)
     {
-        ASActivity *demoActivity = new ASActivity(demoPostData, this);
+        ASActivity *demoActivity = new ASActivity(demoPostData, "", this);
         Post *demoPost = new Post(demoActivity,
                                   false, // Not highlighted
                                   false, // Not standalone
@@ -814,7 +814,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             // The difference in pending posts is in the older pages, so doesn't count
             this->pendingToReceiveNextTime = 0;
 
-            // FIXME 1.3.x: On first load, should display the "pending" number
+            // FIXME 1.3.5: On first load, should display the "pending" number
             // at the bottom or at the "older" button
         }
         else
@@ -847,6 +847,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     int newPostCount = 0;
     int newHighlightedPostsCount = 0;
+    int newDirectPostsCount = 0;
+    int newHLByFilterPostsCount = 0;
     int newDeletedPostsCount = 0;
     int newFilteredPostsCount = 0;
     bool allNewPostsCounted = false;
@@ -884,7 +886,9 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
                                                        .value("id").toString());
             }
 
-            ASActivity *activity = new ASActivity(activityMap, this);
+            ASActivity *activity = new ASActivity(activityMap,
+                                                  pController->currentUserId(),
+                                                  this);
 
             // See if it's deleted
             QString postDeletedTime = activity->object()->getDeletedTime();
@@ -978,9 +982,20 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
                 connect(newPost, SIGNAL(postRead(bool)),
                         this, SLOT(decreaseUnreadPostsCount(bool)));
 
-                if (newPost->getHighlightType() != Post::NoHighlight)
+                int highlightType = newPost->getHighlightType();
+                if (highlightType != Post::NoHighlight)
                 {
                     ++newHighlightedPostsCount;
+
+                    if (highlightType == Post::MessageForUserHighlight)
+                    {
+                        ++newDirectPostsCount;
+                    }
+
+                    if (highlightType == Post::FilterRulesHighlight)
+                    {
+                        ++newHLByFilterPostsCount;
+                    }
                 }
             }
 
@@ -1043,6 +1058,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
              << "\nActual total new from previous update:" << totalPostDifference
              << "\nNewest post ID:" << previousNewestPostId
              << "\nNew highlighted:" << newHighlightedPostsCount
+             << "\n------ New direct:" << newDirectPostsCount
+             << "\n------ New HL by filter:" << newHLByFilterPostsCount
              << "\nNew deleted: " << newDeletedPostsCount
              << "\nNew filtered out: " << newFilteredPostsCount
              << "\nTotal posts:" << fullTimelinePostCount
@@ -1057,9 +1074,12 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     if (gettingNew)
     {
-        emit timelineRendered(this->timelineType, newPostCount,
-                              newHighlightedPostsCount, newDeletedPostsCount,
-                              newFilteredPostsCount, pendingToReceiveNextTime);
+        emit timelineRendered(this->timelineType,
+                              newPostCount, newHighlightedPostsCount,
+                              newDirectPostsCount, newHLByFilterPostsCount,
+                              newDeletedPostsCount, newFilteredPostsCount,
+                              pendingToReceiveNextTime);
+
         emit unreadPostsCountChanged(this->timelineType,
                                      unreadPostsCount,
                                      highlightedPostsCount,
@@ -1073,10 +1093,14 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
     }
     else
     {
-        emit timelineRendered(this->timelineType, postListSize,
-                              -1, newDeletedPostsCount,
-                              newFilteredPostsCount, -1);
-        emit unreadPostsCountChanged(this->timelineType, 0, 0,
+        emit timelineRendered(this->timelineType,
+                              postListSize, -1, // Highlighted counts (direct and by filter)
+                              -1, -1,           // are irrelevant in this case
+                              newDeletedPostsCount, newFilteredPostsCount,
+                              -1);
+
+        emit unreadPostsCountChanged(this->timelineType,
+                                     0, 0,
                                      fullTimelinePostCount);
     }
 
@@ -1155,7 +1179,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
                                      QString actorId, QString actorName,
                                      QString actorUrl)
 {
-    // FIXME: handle updating likes in comments
+    // FIXME 1.3.5: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
@@ -1168,7 +1192,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
 void TimeLine::removeLikesFromMinorFeed(QString objectId, QString objectType,
                                         QString actorId)
 {
-    // FIXME: handle updating likes in comments
+    // FIXME 1.3.5: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
