@@ -88,6 +88,8 @@ signals:
     void timelineRendered(PumpController::requestTypes timelineType,
                           int newPostCount,
                           int highlightedPostsCount,
+                          int directPostsCount,
+                          int highlightedByFilterCount,
                           int deletedPostsCount,
                           int filteredPostsCount,
                           int pendingForNextUpdate);
